==> qastools_1.1.0.orig.tar.xz: qastools-v1.1.0/shared/src/wdg/switches_pad_widgets_group.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "wdg/pad_proxies_group.hpp"
#include "wdg/switches_pad_widgets.hpp"
#include <QGridLayout>
#include <QLabel>
#include <QPen>
#include <QVBoxLayout>
#include <QWidget>
#include <vector>

namespace Wdg
{

/// @brief Switches_Pad_Widgets_Group
///
class Switches_Pad_Widgets_Group : public QWidget
{
  // Public typedefs
  public:
  using Widgets_Vector = ::std::vector< ::Wdg::Switches_Pad_Widgets * >;

  // Public methods
  public:
  // -- Construction

  Switches_Pad_Widgets_Group ( QWidget * parent_n = nullptr );

  ~Switches_Pad_Widgets_Group ();

  void
  clear_widgets ();

  // -- Label

  QLabel *
  label ()
  {
    return _label;
  }

  void
  set_label ( QLabel * wdg_n );

  // -- Widgets list

  unsigned int
  num_widgets () const
  {
    return _widgets.size ();
  }

  void
  append_widgets ( ::Wdg::Switches_Pad_Widgets * wdgs_n );

  const Switches_Pad_Widgets *
  widgets ( int idx_n ) const
  {
    return _widgets[ idx_n ];
  }

  ::Wdg::Switches_Pad_Widgets *
  widgets ( int idx_n )
  {
    return _widgets[ idx_n ];
  }

  // -- Stem pen

  void
  set_stem_pen ( const QPen & pen_n )
  {
    _stem_pen = pen_n;
  }

  // Protected methods
  private:
  QVBoxLayout *
  lay_vbox ()
  {
    return static_cast< QVBoxLayout * > ( layout () );
  }

  int
  enum_spacing () const;

  // Event handling

  bool
  eventFilter ( QObject * watched_n, QEvent * event_n ) override;

  void
  paintEvent ( QPaintEvent * event_n ) override;

  // Private attributes
  private:
  Widgets_Vector _widgets;
  QLabel * _label = nullptr;
  QGridLayout * _lay_grid = nullptr;
  QPen _stem_pen;
};

} // namespace Wdg

==> qastools_1.2.0.orig.tar.xz: qastools-v1.2.0/shared/src/wdg/switches_pad_widgets_group.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "wdg/pad_proxies_group.hpp"
#include "wdg/switches_pad_widgets.hpp"
#include <QGridLayout>
#include <QLabel>
#include <QPen>
#include <QVBoxLayout>
#include <QWidget>
#include <vector>

namespace Wdg
{

/// @brief Switches_Pad_Widgets_Group
///
class Switches_Pad_Widgets_Group : public QWidget
{
  // Public typedefs
  public:
  using Widgets_Vector = std::vector< Wdg::Switches_Pad_Widgets * >;

  public:
  // -- Construction

  Switches_Pad_Widgets_Group ( QWidget * parent_n = nullptr );

  ~Switches_Pad_Widgets_Group ();

  void
  clear_widgets ();

  // -- Label

  QLabel *
  label ()
  {
    return _label;
  }

  void
  set_label ( QLabel * wdg_n );

  // -- Widgets list

  unsigned int
  num_widgets () const
  {
    return _widgets.size ();
  }

  void
  append_widgets ( Wdg::Switches_Pad_Widgets * wdgs_n );

  const Switches_Pad_Widgets *
  widgets ( int idx_n ) const
  {
    return _widgets[ idx_n ];
  }

  Wdg::Switches_Pad_Widgets *
  widgets ( int idx_n )
  {
    return _widgets[ idx_n ];
  }

  // -- Stem pen

  void
  set_stem_pen ( const QPen & pen_n )
  {
    _stem_pen = pen_n;
  }

  // Protected methods
  private:
  QVBoxLayout *
  lay_vbox ()
  {
    return static_cast< QVBoxLayout * > ( layout () );
  }

  int
  enum_spacing () const;

  // Event handling

  bool
  eventFilter ( QObject * watched_n, QEvent * event_n ) override;

  void
  paintEvent ( QPaintEvent * event_n ) override;

  private:
  // -- Attributes
  Widgets_Vector _widgets;
  QLabel * _label = nullptr;
  QGridLayout * _lay_grid = nullptr;
  QPen _stem_pen;
};

} // namespace Wdg
